==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/WARRANTYVMRSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour WARRANTYVMRSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="WARRANTYVMRSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WARRANTYVMRSID_Type", propOrder = {
    "warrantyid",
    "vmrscode"
})
public class WARRANTYVMRSID_Type {

    @XmlElement(name = "WARRANTYID", required = true)
    protected WARRANTYID_Type warrantyid;
    @XmlElement(name = "VMRSCODE", required = true)
    protected VMRSCODE_Type vmrscode;

    /**
     * Obtient la valeur de la propriété warrantyid.
     * 
     * @return
     *     possible object is
     *     {@link WARRANTYID_Type }
     *     
     */
    public WARRANTYID_Type getWARRANTYID() {
        return warrantyid;
    }

    /**
     * Définit la valeur de la propriété warrantyid.
     * 
     * @param value
     *     allowed object is
     *     {@link WARRANTYID_Type }
     *     
     */
    public void setWARRANTYID(WARRANTYID_Type value) {
        this.warrantyid = value;
    }

    /**
     * Obtient la valeur de la propriété vmrscode.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public VMRSCODE_Type getVMRSCODE() {
        return vmrscode;
    }

    /**
     * Définit la valeur de la propriété vmrscode.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public void setVMRSCODE(VMRSCODE_Type value) {
        this.vmrscode = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/WARRANTYVMRSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for WARRANTYVMRSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WARRANTYVMRSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WARRANTYVMRSID_Type", propOrder = {
    "warrantyid",
    "vmrscode"
})
public class WARRANTYVMRSID_Type {

    @XmlElement(name = "WARRANTYID", required = true)
    protected WARRANTYID_Type warrantyid;
    @XmlElement(name = "VMRSCODE", required = true)
    protected VMRSCODE_Type vmrscode;

    /**
     * Gets the value of the warrantyid property.
     * 
     * @return
     *     possible object is
     *     {@link WARRANTYID_Type }
     *     
     */
    public WARRANTYID_Type getWARRANTYID() {
        return warrantyid;
    }

    /**
     * Sets the value of the warrantyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WARRANTYID_Type }
     *     
     */
    public void setWARRANTYID(WARRANTYID_Type value) {
        this.warrantyid = value;
    }

    /**
     * Gets the value of the vmrscode property.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public VMRSCODE_Type getVMRSCODE() {
        return vmrscode;
    }

    /**
     * Sets the value of the vmrscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public void setVMRSCODE(VMRSCODE_Type value) {
        this.vmrscode = value;
    }

}
